
#ifndef CLASS126_HPP
#define CLASS126_HPP
class Treatment_service_order_revision
	{
	/*design in subject "DIM_Orders_observations" */
	/*design in subject "RIM_Patient_encounters" */
	/*design in subject "RIM_Patient_service_order" */
	/*design in subject "STW_C04_Orders_observations" */

	/*design comment 
:/%Description%/The collection of characteristics for a pharmacy treatment order that can be revised during the course of processing the order.  Pharmacy encoding is an example of a process that may revise order characteristics.  This "revisions" class allows tracking of changes made to the order, and representation of the order at any stage in its processing.

Rationale: Class name changed to better represent usage.  There is no sense in which the contents of this class represent an "item" of the pharmacy order.

OpenIssue: Note that this is used to surface the information carred in the Pharmacy Encoded segment of v2.3, and this name revision may need to be changed to be more appropriate.
/%hxID%/2935
/%PrimarySubjectArea%/RIM_Patient_service_order
*/
public:
private:
	/*design comment dispense_package_method_cd 
:/%Description%/the method by which treatment is dispensed, eg. Traditional, unit-dose, floor stock, automatic dispensing

Rationale: previously unmatched V2.3 field

OpenIssue: 
/%Datatype%/ID
/%hxID%/3222
/%HL7v23Field%/01222
*/
	int dispense_package_method_cd;
	/*design comment dispense_package_size_amt 
:/%Description%/This field contains the size of package to be dispensed

Rationale: previously unmatched V2.3 field

OpenIssue: 
/%Datatype%/NM
/%hxID%/3223
/%HL7v23Field%/01220
*/
	int dispense_package_size_amt;
	/*design comment give_indication_cd 
:/%Description%/condition or problem for which the drug/treatment was prescribed

Rationale: previously unmatched V2.3 field

OpenIssue: 
/%Datatype%/CE
/%hxID%/3224
/%HL7v23Field%/01128
*/
	int give_indication_cd;
	/*design comment give_per_time_unit_cd 
:/%Description%/The number of gives per unit of time.
/%Datatype%/ST
/%hxID%/3225
/%HL7v23Field%/00308, 00331
*/
	int give_per_time_unit_cd;
	/*design comment give_rate_amt 
:/%Description%/The rate of give for the medication.
/%Datatype%/ST
/%hxID%/3226
/%HL7v23Field%/00332
*/
	int give_rate_amt;
	/*design comment last_refilled_dttm 
:/%Description%/A indication that the pharmacy order required human review.
/%Datatype%/ID
/%hxID%/3227
/%HL7v23Field%/00307
*/
	int last_refilled_dttm;
	/*design comment max_give_amt 
:/%Description%/The maximum amount of medication to be administered.
/%Datatype%/NM
/%hxID%/3228
/%HL7v23Field%/00294, 00319
*/
	int max_give_amt;
	/*design comment min_give_amt 
:/%Description%/The minimum amount of medication to be administered.
/%Datatype%/NM
/%hxID%/3229
/%HL7v23Field%/00293, 00318
*/
	int min_give_amt;
	/*design comment needs_human_review_ind 
:/%Description%/An indication that a pharmacy order for an out of formulary item is authorized.
/%hxID%/3230
*/
	int needs_human_review_ind;
	/*design comment order_revision_PTcomp 
:/%Description%/Specification for one component of the ordered medication or treatment

Rationale: 

OpenIssue: 
/%Datatype%/PTcomp
/%hxID%/3231
/%HL7v23Field%/00316
*/
	int order_revision_PTcomp;
	/*design comment order_revision_PTrout 
:/%Description%/Specification for one route of administration for the ordered medication or treatment.  Specification includes route, site, administration device and administration method.

Rationale: 

OpenIssue: 
/%Datatype%/PTrout
/%hxID%/3232
/%HL7v23Field%/00310
*/
	int order_revision_PTrout;
	/*design comment order_revision_quantitytiming_qt 
:/%Description%/A means of specifying when the service described by the give notice is to be performed and how frequently.  It is a complex multicomponent field that can have repeats.  The pharmacy or treatment department has the "authority" (and/or necessity) to schedule dispense/give events.  Hence, the pharmacy or treatment department has the responsibility to encode this scheduling information for the pharmacy service order item and pharmacy service give notice.  The quantity/timing for the patient service order does not change: it always specifies the requested give/dispense schedule of the original order 

Rationale: 

OpenIssue: 
/%Datatype%/TQ
/%hxID%/4024
*/
	int order_revision_quantitytiming_qt;
	/*design comment ordered_administration_method_cd 
:/%Description%/The method to be used to administer the medication.
/%Datatype%/CE
/%hxID%/3233
/%HL7v23Field%/00312
*/
	int ordered_administration_method_cd;
	/*design comment prescription_id 
:/%Description%/The information about how many services to perform at one service time and how often the service times are repeated, and to fix duration of the request.  
/%Datatype%/TQ
/%hxID%/3234
/%HL7v23Field%/00221
*/
	int prescription_id;
	/*design comment providers_administration_instruction_cd 
:/%Description%/the ordering provider's instructions to the patient or the provider administering the drug or treatment

Rationale: previously unmatched V2.3 field

OpenIssue: 
/%Datatype%/CE
/%hxID%/3235
/%HL7v23Field%/00298
*/
	int providers_administration_instruction_cd;
	/*design comment refills_allowed_qty 
:/%Description%/The number of refills doses dispensed.
/%Datatype%/NM
/%hxID%/3236
/%HL7v23Field%/00327
*/
	int refills_allowed_qty;
	/*design comment refills_doses_dispensed_qty 
:/%Description%/The number of refills remaining.
/%Datatype%/NM
/%hxID%/3237
/%HL7v23Field%/00326
*/
	int refills_doses_dispensed_qty;
	/*design comment refills_remaining_qty 
:/%Description%/The number of refills remaining.
/%Datatype%/NM
/%hxID%/3238
/%HL7v23Field%/00326
*/
	int refills_remaining_qty;
	/*design comment substitution_status_cd 
:/%Description%/Substitution status of the pharmacy order.
/%Datatype%/ID
/%hxID%/3239
/%HL7v23Field%/00322
*/
	int substitution_status_cd;
	/*design comment suppliers_dispensing_instruction_cd 
:/%Description%/the pharmacy or treatment supplier's provider-generated special instructions to the provider dispensing/administering the order

Rationale: previously unmatched V2.3 field

OpenIssue: 
/%Datatype%/CE
/%hxID%/3240
/%HL7v23Field%/00330
*/
	int suppliers_dispensing_instruction_cd;
	/*design comment total_daily_dose_amt 
:/%Description%/the total daily dose for this particular pharmaceutical as expressed in terms of actual dispense units.

Rationale: all RXE fields should appear in RIM08 Pharmacy_service_order_item

OpenIssue: 
/%Datatype%/CQ
/%hxID%/3241
/%HL7v23Field%/00329
*/
	int total_daily_dose_amt;
	/*design comment total_daily_dose_cd 
:/%Description%/Total daily dosage code.
/%Datatype%/CQ
/%hxID%/3242
/%HL7v23Field%/00329
*/
	int total_daily_dose_cd;
	};

#endif
